@@ -1,6 +1,5 @@
-# $Id: mkinpredict.R 133 2013-11-04 09:16:12Z jranke $
-
-# Copyright (C) 2010-2012 Johannes Ranke
+# Copyright (C) 2010-2014 Johannes Ranke
+# Some lines in this code are copyright (C) 2013 Eurofins Regulatory AG
 # Contact: jranke@uni-bremen.de
 
 # This file is part of the R package mkin
@@ -18,7 +17,10 @@
 # You should have received a copy of the GNU General Public License along with
 # this program. If not, see <http://www.gnu.org/licenses/>
 
-mkinpredict <- function(mkinmod, odeparms, odeini, outtimes, solution_type = "deSolve", map_output = TRUE, atol = 1e-8, rtol = 1e-10, ...) {
+mkinpredict <- function(mkinmod, odeparms, odeini, 
+			outtimes, solution_type = "deSolve", 
+			method.ode = "lsoda", atol = 1e-8, rtol = 1e-10,
+			map_output = TRUE, ...) {
 
   # Get the names of the state variables in the model
   mod_vars <- names(mkinmod$diffs)
@@ -96,6 +98,7 @@ mkinpredict <- function(mkinmod, odeparms, odeini, outtimes, solution_type = "de
       times = outtimes,
       func = mkindiff, 
       parms = odeparms,
+      method = method.ode,
       atol = atol,
       rtol = rtol,
       ...
